using Android.Content;
using Android.Views;
using Android.Views.Animations;

namespace Mobile.Droid.Extensions
{
  // invoke with anyView.BringViewInWithAnimation/TakeViewOutWithAnimation
  // where animation param is predefined animations from xml, code, etc.
  // e.g. inAnimation = AnimationUtils.LoadAnimation(Activity, Resource.Animation.bottom_slide_in);

    public static class ViewExtensions
    {
        /// <summary>
        /// Bring view on to screen. You may need to enable the 'RunOnUiThread' depending
        /// on where you're calling this from
        /// </summary>
        /// <param name="viewToAnimate">the view</param>
        /// <param name="animation"></param>
        public static void BringViewInWithAnimation(this View viewToAnimate, Animation animation)
        {
            //RunOnUiThread(() =>
            //{
                animation.Interpolator = new OvershootInterpolator(1.0f);
                viewToAnimate.Visibility = ViewStates.Visible;
                viewToAnimate.StartAnimation(animation);
            //});
        }
        
        /// <summary>
        /// Take view out of screen. You may need to enable the 'RunOnUiThread' depending
        /// on where you're calling this from
        /// </summary>
        /// <param name="viewToAnimate">the view</param>
        /// <param name="animation"></param>        
        public static void TakeViewOutWithAnimation(this View viewToAnimate, Animation outAnimation)
        {
            //RunOnUiThread(() =>
            //{
                viewToAnimate.BringToFront();
                outAnimation.Interpolator = new AccelerateInterpolator();
                viewToAnimate.StartAnimation(outAnimation);
                viewToAnimate.Visibility = ViewStates.Gone;
            // });
        }

        /// <summary>
        /// 'Pop' view out from nothing (or whatever you had it scaled to, before)
        /// </summary>
        /// <param name="viewToAnimate">the view</param>
        /// <param name="animation"></param>        
        public static ViewPropertyAnimator WormholeEnter(this View viewToAnimate, float maxScale)
        {
            return viewToAnimate.Animate()
                            .ScaleX(maxScale)
                            .ScaleY(maxScale)
                            .SetDuration(500)
                            .WithEndAction(new Runnable(() => viewToAnimate.Visibility = ViewStates.Visible));
        }

        /// <summary>
        /// View disappears (or visibly shrinks) down to whatever you scale it to, and then disappears.
        /// Designed to pull views off-screen
        /// </summary>
        /// <param name="viewToAnimate">the view</param>
        /// <param name="animation"></param>        
        public static ViewPropertyAnimator WormholeExit(this View viewToAnimate)
        {
            return viewToAnimate.Animate()
                            .ScaleX(0f)
                            .ScaleY(0f)
                            .SetDuration(500)
                            .WithEndAction(new Runnable(() => viewToAnimate.Visibility = ViewStates.Gone));
        }
        
    }
}